@@ -300,7 +300,7 @@ class Unmarshaller:
                 self._unix_fds.extend(
                     ARRAY("i", data[: len(data) - (len(data) % MAX_UNIX_FDS_SIZE)])
                 )
-        if msg == b"":
+        if not msg:
             raise EOFError()
         self._buf += msg
         if len(self._buf) < pos:
@@ -322,7 +322,7 @@ class Unmarshaller:
                 if errno == EAGAIN or errno == EWOULDBLOCK:
                     raise MARSHALL_STREAM_END_ERROR
                 raise
-            if data == b"":
+            if not data:
                 raise EOFError()
             self._buf += data
             if len(self._buf) >= pos:
@@ -333,7 +333,7 @@ class Unmarshaller:
         data = self._stream_reader(missing_bytes)  # type: ignore[misc]
         if data is None:
             raise MARSHALL_STREAM_END_ERROR
-        if data == b"":
+        if not data:
             raise EOFError()
         self._buf += data
         if len(self._buf) < pos:
@@ -622,26 +622,26 @@ class Unmarshaller:
         ):
             self._is_native = 1  # pragma: no cover
             self._body_len = _cast_uint32_native(  # type: ignore[name-defined] # pragma: no cover
-                self._buf, 4
+                buffer, 4
             )
             self._serial = _cast_uint32_native(  # type: ignore[name-defined] # pragma: no cover
-                self._buf, 8
+                buffer, 8
             )
             self._header_len = _cast_uint32_native(  # type: ignore[name-defined] # pragma: no cover
-                self._buf, 12
+                buffer, 12
             )
         elif endian == LITTLE_ENDIAN:
             (
                 self._body_len,
                 self._serial,
                 self._header_len,
-            ) = UNPACK_HEADER_LITTLE_ENDIAN(self._buf, 4)
+            ) = UNPACK_HEADER_LITTLE_ENDIAN(buffer, 4)
             self._uint32_unpack = UINT32_UNPACK_LITTLE_ENDIAN
             self._int16_unpack = INT16_UNPACK_LITTLE_ENDIAN
             self._uint16_unpack = UINT16_UNPACK_LITTLE_ENDIAN
         elif endian == BIG_ENDIAN:
             self._body_len, self._serial, self._header_len = UNPACK_HEADER_BIG_ENDIAN(
-                self._buf, 4
+                buffer, 4
             )
             self._uint32_unpack = UINT32_UNPACK_BIG_ENDIAN
             self._int16_unpack = INT16_UNPACK_BIG_ENDIAN
