@@ -381,10 +381,7 @@ class Variant:
     construct this class directly for use in message bodies sent over the bus.
 
     :ivar signature: The signature for this variant. Must be a single complete type.
-    :vartype signature: str
-
-    :ivar signature_type: The parsed signature of this variant.
-    :vartype signature_type: :class:`SignatureType`
+    :vartype signature: str or SignatureTree or SignatureType
 
     :ivar value: The value of this variant. Must correspond to the signature.
     :vartype value: Any
@@ -438,14 +435,12 @@ class Variant:
         )
 
 
-@lru_cache(maxsize=None)
-def get_signature_tree(signature: str) -> SignatureTree:
-    """Get a signature tree for the given signature.
+get_signature_tree = lru_cache(maxsize=None)(SignatureTree)
+"""Get a signature tree for the given signature.
 
-    :param signature: The signature to get a tree for.
-    :type signature: str
+:param signature: The signature to get a tree for.
+:type signature: str
 
-    :returns: The signature tree for the given signature.
-    :rtype: :class:`SignatureTree`
-    """
-    return SignatureTree(signature)
+:returns: The signature tree for the given signature.
+:rtype: :class:`SignatureTree`
+"""
